==> openshift-model-operatorhub-5.10.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1/OperatorStatusFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class OperatorStatusFluentImpl<A extends io.fabric8.openshift.api.model.operatorhub.v1.OperatorStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operatorhub.v1.OperatorStatusFluent<A>{
  public OperatorStatusFluentImpl() {
  }
  public OperatorStatusFluentImpl(io.fabric8.openshift.api.model.operatorhub.v1.OperatorStatus instance) {
    this.withComponents(instance.getComponents()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.operatorhub.v1.ComponentsBuilder components;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildComponents instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operatorhub.v1.Components getComponents() {
    return this.components!=null?this.components.build():null;
  }
  public io.fabric8.openshift.api.model.operatorhub.v1.Components buildComponents() {
    return this.components!=null?this.components.build():null;
  }
  public A withComponents(io.fabric8.openshift.api.model.operatorhub.v1.Components components) {
    _visitables.get("components").remove(this.components);
    if (components!=null){ this.components= new io.fabric8.openshift.api.model.operatorhub.v1.ComponentsBuilder(components); _visitables.get("components").add(this.components);} return (A) this;
  }
  public java.lang.Boolean hasComponents() {
    return this.components != null;
  }
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorStatusFluent.ComponentsNested<A> withNewComponents() {
    return new io.fabric8.openshift.api.model.operatorhub.v1.OperatorStatusFluentImpl.ComponentsNestedImpl();
  }
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorStatusFluent.ComponentsNested<A> withNewComponentsLike(io.fabric8.openshift.api.model.operatorhub.v1.Components item) {
    return new io.fabric8.openshift.api.model.operatorhub.v1.OperatorStatusFluentImpl.ComponentsNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorStatusFluent.ComponentsNested<A> editComponents() {
    return withNewComponentsLike(getComponents());
  }
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorStatusFluent.ComponentsNested<A> editOrNewComponents() {
    return withNewComponentsLike(getComponents() != null ? getComponents(): new io.fabric8.openshift.api.model.operatorhub.v1.ComponentsBuilder().build());
  }
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorStatusFluent.ComponentsNested<A> editOrNewComponentsLike(io.fabric8.openshift.api.model.operatorhub.v1.Components item) {
    return withNewComponentsLike(getComponents() != null ? getComponents(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OperatorStatusFluentImpl that = (OperatorStatusFluentImpl) o;
    if (components != null ? !components.equals(that.components) :that.components != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(components,  additionalProperties,  super.hashCode());
  }
  public class ComponentsNestedImpl<N> extends io.fabric8.openshift.api.model.operatorhub.v1.ComponentsFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1.OperatorStatusFluent.ComponentsNested<N>> implements io.fabric8.openshift.api.model.operatorhub.v1.OperatorStatusFluent.ComponentsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ComponentsNestedImpl(io.fabric8.openshift.api.model.operatorhub.v1.Components item) {
      this.builder = new io.fabric8.openshift.api.model.operatorhub.v1.ComponentsBuilder(this, item);
    }
    ComponentsNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operatorhub.v1.ComponentsBuilder(this);
    }
    io.fabric8.openshift.api.model.operatorhub.v1.ComponentsBuilder builder;
    public N and() {
      return (N) OperatorStatusFluentImpl.this.withComponents(builder.build());
    }
    public N endComponents() {
      return and();
    }
    
  }
  
}

==> openshift-model-operatorhub-5.12.3-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1/OperatorStatusFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class OperatorStatusFluentImpl<A extends io.fabric8.openshift.api.model.operatorhub.v1.OperatorStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operatorhub.v1.OperatorStatusFluent<A>{
  public OperatorStatusFluentImpl() {
  }
  public OperatorStatusFluentImpl(io.fabric8.openshift.api.model.operatorhub.v1.OperatorStatus instance) {
    this.withComponents(instance.getComponents()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.operatorhub.v1.ComponentsBuilder components;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildComponents instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operatorhub.v1.Components getComponents() {
    return this.components!=null?this.components.build():null;
  }
  public io.fabric8.openshift.api.model.operatorhub.v1.Components buildComponents() {
    return this.components!=null?this.components.build():null;
  }
  public A withComponents(io.fabric8.openshift.api.model.operatorhub.v1.Components components) {
    _visitables.get("components").remove(this.components);
    if (components!=null){ this.components= new io.fabric8.openshift.api.model.operatorhub.v1.ComponentsBuilder(components); _visitables.get("components").add(this.components);} return (A) this;
  }
  public java.lang.Boolean hasComponents() {
    return this.components != null;
  }
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorStatusFluent.ComponentsNested<A> withNewComponents() {
    return new io.fabric8.openshift.api.model.operatorhub.v1.OperatorStatusFluentImpl.ComponentsNestedImpl();
  }
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorStatusFluent.ComponentsNested<A> withNewComponentsLike(io.fabric8.openshift.api.model.operatorhub.v1.Components item) {
    return new io.fabric8.openshift.api.model.operatorhub.v1.OperatorStatusFluentImpl.ComponentsNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorStatusFluent.ComponentsNested<A> editComponents() {
    return withNewComponentsLike(getComponents());
  }
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorStatusFluent.ComponentsNested<A> editOrNewComponents() {
    return withNewComponentsLike(getComponents() != null ? getComponents(): new io.fabric8.openshift.api.model.operatorhub.v1.ComponentsBuilder().build());
  }
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorStatusFluent.ComponentsNested<A> editOrNewComponentsLike(io.fabric8.openshift.api.model.operatorhub.v1.Components item) {
    return withNewComponentsLike(getComponents() != null ? getComponents(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OperatorStatusFluentImpl that = (OperatorStatusFluentImpl) o;
    if (components != null ? !components.equals(that.components) :that.components != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(components,  additionalProperties,  super.hashCode());
  }
  public class ComponentsNestedImpl<N> extends io.fabric8.openshift.api.model.operatorhub.v1.ComponentsFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1.OperatorStatusFluent.ComponentsNested<N>> implements io.fabric8.openshift.api.model.operatorhub.v1.OperatorStatusFluent.ComponentsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ComponentsNestedImpl(io.fabric8.openshift.api.model.operatorhub.v1.Components item) {
      this.builder = new io.fabric8.openshift.api.model.operatorhub.v1.ComponentsBuilder(this, item);
    }
    ComponentsNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operatorhub.v1.ComponentsBuilder(this);
    }
    io.fabric8.openshift.api.model.operatorhub.v1.ComponentsBuilder builder;
    public N and() {
      return (N) OperatorStatusFluentImpl.this.withComponents(builder.build());
    }
    public N endComponents() {
      return and();
    }
    
  }
  
}
